@@ -2,7 +2,6 @@
 use strict;
 use Data::Dumper;
 use Parse::Eyapp;
-use IO::Interactive qw(is_interactive);
 
 my $translationscheme = q{
 %{
@@ -23,6 +22,15 @@ our %sym; # symbol table
 %left   '-' '+'
 %left   '*' '/'
 
+%lexer {
+    s/^\s+//;
+    
+    s/^([0-9]+(?:\.[0-9]+)?)// and return('NUM',$1);
+    s/^([A-Za-z][A-Za-z0-9_]*)// and return('VAR',$1);
+    s/^(.)// and return($1,$1);
+}
+
+
 %%
 line:       %name EXP  
               exp <+ ';'> /* Expressions separated by semicolons */ 
@@ -52,28 +60,6 @@ exp:
 ;
 
 %%
-# tail code is available at tree construction time 
-sub _Error {
-  die "Syntax error.\n";
-}
-
-sub _Lexer {
-    my($parser)=shift;
-
-    for ($parser->YYData->{INPUT}) {
-        s/^\s+//;
-        $_ or  return('',undef);
-        s/^([0-9]+(?:\.[0-9]+)?)// and return('NUM',$1);
-        s/^([A-Za-z][A-Za-z0-9_]*)// and return('VAR',$1);
-        s/^(.)// and return($1,$1);
-    }
-    return('',undef);
-}
-
-sub Run {
-    my($self)=shift;
-    return $self->YYParse( yylex => \&_Lexer, yyerror => \&_Error );
-}
 }; # end translation scheme
 
 sub TERMINAL::info { $_[0]->attr }
@@ -85,9 +71,15 @@ my $p = Parse::Eyapp->new_grammar(
   outputfile => 'main.pm');
 die $p->qtables() if $p->Warnings;
 my $parser = main->new();
-print "Write a sequence of arithmetic expressions: " if is_interactive();
-$parser->YYData->{INPUT} = <>;
-my $t = $parser->Run() or die "Syntax Error analyzing input";
+
+$parser->slurp_file(
+  '', 
+  "Write a sequence of semicolon separated arithmetic expressions: ",
+  "\n"
+);
+
+my $t = $parser->YYParse() or die "Syntax Error analyzing input";
+
 $t->translation_scheme;
 
 $Parse::Eyapp::Node::INDENT = 2;
